package fr.sanchezm.attestationsCovid19.data.db.entity

import java.text.SimpleDateFormat
import java.util.*

const val PATTERN = "dd/MM/yyyy 'à' HH'h'mm"

//@Entity(tableName = "attestation")
data class Attestation(
    val profile: Profile,
    val exitDate: String,
    val exitHour: String,
    var createAt: Long,
    val reasons: List<Int>
) {
    override fun toString(): String {
        return "Cree le: ${getDate(createAt)}; $profile; Sortie: ${getExitDateFormatted()}; Motifs: ${getMotifsText()}"
    }

    fun getNameFormatted(): String = "${profile.firstName} ${profile.lastName}"

    fun getCreatedAtFormattedDate(): String = getDate(createAt)

    fun getExitDateFormatted(): String = "$exitDate a $exitHour"

    fun getMotifsFormatted(): String = getMotifsText().replace("-", " ")

    private fun getMotifsText(): String {
        val motifs = StringBuilder()

        reasons.forEach { motifs.append(getMotifText(it), "-") }
        return motifs.toString().dropLast(1)
    }

    private fun getDate(dateTime: Long): String = SimpleDateFormat(PATTERN, Locale.FRANCE).format(Date(dateTime))

    private fun getMotifText(i: Int): String {
        return when (i) {
            1 -> "travail"
            2 -> "courses"
            3 -> "sante"
            4 -> "famille"
            5 -> "sport"
            6 -> "judiciare"
            7 -> "missions"
            else -> "Error $i not found"
        }
    }

}