package fr.sanchezm.attestationsCovid19.utilities

import android.content.Context
import android.os.Environment
import fr.sanchezm.attestationsCovid19.data.db.MyDatabase
import fr.sanchezm.attestationsCovid19.data.repository.AttestationRepository
import fr.sanchezm.attestationsCovid19.data.repository.ConfigRepository
import fr.sanchezm.attestationsCovid19.data.repository.ProfileRepository
import fr.sanchezm.attestationsCovid19.ui.add.AddViewModelFactory
import fr.sanchezm.attestationsCovid19.ui.attestations.AttestationsViewModelFactory
import fr.sanchezm.attestationsCovid19.ui.qrcode.QrCodeViewModelFactory

object InjectorUtils {

    fun provideAddViewModelFactory(context: Context): AddViewModelFactory =
        AddViewModelFactory(
            getConfigRepo(context),
            getProfileRepo(context),
            getAttestationRepo(context)
        )

    fun provideAttestationViewModel(context: Context): AttestationsViewModelFactory =
        AttestationsViewModelFactory(
            getConfigRepo(context),
            getAttestationRepo(context)
        )

    fun provideQrCodeViewModel(context: Context): QrCodeViewModelFactory =
        QrCodeViewModelFactory(
            getConfigRepo(context),
            getAttestationRepo(context)
        )

    fun providePdfUtils(context: Context): PdfUtils =
        PdfUtils.getInstance(context.assets, getMyFilesDir(context))

    private fun getMyFilesDir(context: Context): String =
        context.getExternalFilesDir(Environment.DIRECTORY_DOWNLOADS)?.path!!

    private fun getAttestationRepo(context: Context): AttestationRepository =
        AttestationRepository.getInstance(
            MyDatabase.invoke(context, getMyFilesDir(context)).attestationDao()
        )

    private fun getProfileRepo(context: Context): ProfileRepository = ProfileRepository.getInstance(
        MyDatabase.invoke(context, getMyFilesDir(context)).profileDao()
    )

    private fun getConfigRepo(context: Context): ConfigRepository = ConfigRepository.getInstance(
        MyDatabase.invoke(context, getMyFilesDir(context)).configDao()
    )

}